pub fn corner_lattice(
quads: &[LinkedQuad],
coords: &HashMap<usize, QuadGrid>,
) -> HashMap<(i32, i32), ((f32, f32), usize)>Expand description
Every lattice point referenced by at least one quad corner, mapped to its averaged position and the number of referencing quad corners.